<?php
class Item
{
    private $cat;
    private $id;
    private $img;
    private $name;
    private $desc;
    private $url;
    private $urlText;
    private $tagLine;
    private $buy;
    private $buyText;
    private $buyTitle;
    private $icon;
    private $catName;
    public function __construct($cat, $id)
    {
        $this->cat = $cat;
        $this->id = $id;
        $this->img = "assets/img/portfolio/$cat-$id.jpg";
        $this->catName = ucfirst($this->cat);
        $this->name = ucfirst($this->cat) . " " . $this->id;
        $this->tagLine = "More detailed information about {$this->name} will be available soon";
        $this->urlText = "Learn More";
        $this->buyText = "Get it Now!";
        $this->buyTitle = "Buy Link";
    }

    private function mkUrlLink()
    {
        $urlLink = "<strong>URL</strong>: <a href='{$this->url}'>$this->urlText</a>";
        return $urlLink;
    }
    private function mkBuyLink()
    {
        $buyLink = "<strong>$this->buyTitle</strong>: <a href='{$this->buy}'>$this->buyText</a>";
        return $buyLink;
    }
    public function showDetails()
    {
        $url = $this->mkUrlLink();
        $buy = $this->mkBuyLink();

        echo <<<RENDER
<!-- Portfolio Details Section -->
<section id="portfolio-details" class="portfolio-details section">

    <div class="container" data-aos="fade-up" data-aos-delay="100">

        <div class="row gy-4">

            <div class="col-lg-8">
                <div class="portfolio-details-slider swiper init-swiper">

                    <script type="application/json" class="swiper-config">
                        {
                        "loop": true,
                        "speed": 600,
                        "autoplay": {
                            "delay": 5000
                        },
                        "slidesPerView": "auto",
                        "pagination": {
                            "el": ".swiper-pagination",
                            "type": "bullets",
                            "clickable": true
                        }
                        }
                    </script>

                    <div class="swiper-wrapper align-items-center">

                        <div class="swiper-slide">
                            <img src="{$this->img}" alt="">
                        </div>

                    </div>
                    <div class="swiper-pagination"></div>
                </div>
            </div>

            <div class="col-lg-4">
                <div class="portfolio-info" data-aos="fade-up"
                    data-aos-delay="200">
                    <h3>$this->name</h3>
                    <ul>
                        <li><strong>Category</strong>: $this->catName</li>
                        <li>$url</li>
                        <li>$buy</li>
                    </ul>
                </div>
                <div class="portfolio-description" data-aos="fade-up"
                    data-aos-delay="300">
                    <h5>{$this->tagLine}</h5>
                    <p>
                        {$this->desc}
                    </p>
                </div>
            </div>

        </div>

    </div>

</section><!-- /Portfolio Details Section -->
RENDER;
    }
    public function show()
    {
        $name = $this->name ?: ucfirst($this->cat) . " " . $this->id;
        $tagLine = $this->tagLine ?: "More detailed information about $name will be available soon";
        $link = $this->url ? "[<a href='{$this->url}' target='_blank'>Learn More</a>]" : "";
        echo <<<RENDER
<div
    class="col-lg-4 col-md-6 portfolio-item isotope-item filter-{$this->cat}">
    <div class="portfolio-content h-100">
    <img src="{$this->img}" class="img-fluid"
        alt="">
    <div class="portfolio-info">
        <h4>$name</h4>
        <p>$tagLine</p>
        <a href="{$this->img}" title="$name: $tagLine $link"
        data-gallery="portfolio-gallery-{$this->cat}"
        class="glightbox preview-link"><i
            class="bi bi-zoom-in"></i></a>
        <a href="portfolio.php?cat={$this->cat}&id={$this->id}"
        title="More Details" class="details-link"><i
            class="bi bi-link-45deg"></i></a>
    </div>
    </div>
</div><!-- End Portfolio Item -->
RENDER;
    }

    public function showService()
    {
        echo <<<RENDER
<div class="col-lg-4 col-md-6 service-item d-flex" data-aos="fade-up"
    data-aos-delay="100">
    <div class="icon flex-shrink-0"><i class="bi bi-{$this->icon}"></i>
    </div>
    <div>
        <h4 class="title"><a href="service.php"
            class="stretched-link">{$this->name}</a></h4>
        <p class="description">
        {$this->desc}
        </p>
    </div>
</div><!-- End Service Item -->
RENDER;
    }

    /**
     * @param mixed $catName 
     * @return self
     */
    public function setCatName($catName): self
    {
        $this->catName = $catName;
        return $this;
    }

    /**
     * @return mixed
     */
    public function getImg()
    {
        return $this->img;
    }

    /**
     * @return mixed
     */
    public function getName()
    {
        return $this->name;
    }

    /**
     * @param mixed $name 
     * @return self
     */
    public function setName($name): self
    {
        $this->name = $name;
        return $this;
    }

    /**
     * @return mixed
     */
    public function getDesc()
    {
        return $this->desc;
    }

    /**
     * @param mixed $desc 
     * @return self
     */
    public function setDesc($desc): self
    {
        $this->desc = $desc;
        return $this;
    }

    /**
     * @param mixed $url 
     * @return self
     */
    public function setUrl($url): self
    {
        $this->url = $url;
        return $this;
    }

    /**
     * @param mixed $tagLine 
     * @return self
     */
    public function setTagLine($tagLine): self
    {
        $this->tagLine = $tagLine;
        return $this;
    }

    /**
     * @param mixed $buy 
     * @return self
     */
    public function setBuy($buy): self
    {
        $this->buy = $buy;
        return $this;
    }

    /**
     * @param mixed $icon 
     * @return self
     */
    public function setIcon($icon): self
    {
        $this->icon = $icon;
        return $this;
    }

    /**
     * @param mixed $urlText 
     * @return self
     */
    public function setUrlText($urlText): self
    {
        $this->urlText = $urlText;
        return $this;
    }

    /**
     * @param mixed $buyText 
     * @return self
     */
    public function setBuyText($buyText): self
    {
        $this->buyText = $buyText;
        return $this;
    }

    /**
     * @param mixed $buyTitle 
     * @return self
     */
    public function setBuyTitle($buyTitle): self
    {
        $this->buyTitle = $buyTitle;
        return $this;
    }
}
